ProgramLock

Struct ProgramLock 

pub struct ProgramLock { /* private fields */ }
Manages a lock file used to track if an iroh program is already running. Aquired locks write a file to iroh’s application data path containing the process identifier (PID) of the process with the lock. The lock exclusion test requires both a lockfile AND a running process listed at the PID in the file An acquired lock is released either when the object is dropped or when the program stops, which removes the file Invalid or corrupt locks are overwritten on acquisition

Implementations

Source

impl ProgramLock

pub fn new(prog_name: &str) -> Result<Self>

Create a new lock for the given program. This does not yet acquire the lock.

pub fn acquire_or_exit(&mut self) -> &mut Self

Shorthand intended for main functions that need a lock to guard the process

pub fn path(&self) -> &PathBuf

pub fn program_name(&self) -> &str

pub fn is_locked(&mut self) -> Result<bool>

Check if the current program is locked or not.

pub fn active_pid(&mut self) -> Result<Pid>

returns the PID in the lockfile only if the process is active

pub fn acquire(&mut self) -> Result<()>

Try to acquire a lock for this program.

pub fn destroy_without_checking(&self) -> Result<()>