pub struct ProgramLock { /* private fields */ }Expand description
Manages a lock file used to track if an iroh program is already running. Aquired locks write a file to iroh’s application data path containing the process identifier (PID) of the process with the lock. The lock exclusion test requires both a lockfile AND a running process listed at the PID in the file An acquired lock is released either when the object is dropped or when the program stops, which removes the file Invalid or corrupt locks are overwritten on acquisition
Implementations
Sourceimpl ProgramLock
impl ProgramLock
Sourcepub fn new(prog_name: &str) -> Result<Self>
pub fn new(prog_name: &str) -> Result<Self>
Create a new lock for the given program. This does not yet acquire the lock.
Sourcepub fn acquire_or_exit(&mut self) -> &mut Self
pub fn acquire_or_exit(&mut self) -> &mut Self
Shorthand intended for main functions that need a lock to guard the process
pub fn path(&self) -> &PathBuf
pub fn program_name(&self) -> &str
Sourcepub fn active_pid(&mut self) -> Result<Pid>
pub fn active_pid(&mut self) -> Result<Pid>
returns the PID in the lockfile only if the process is active
pub fn destroy_without_checking(&self) -> Result<()>